package fr.univlyon1.tiw1.inscriptions.modele;

import javax.persistence.*;
import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.*;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;

/**
 * Created by ecoquery on 19/10/2016.
 */
@Entity
@XmlType(propOrder = {"title", "start", "end", "emailsInscrits"})
public class Event {
    @Id
    @GeneratedValue
    private int id;
    @NotNull
    private String title;
    @Temporal(TemporalType.TIMESTAMP)
    private Date start;
    @Temporal(TemporalType.TIMESTAMP)
    private Date end;
    @ManyToMany(mappedBy = "inscriptions")
    private Collection<Person> inscrits = new ArrayList<>();

    @XmlAttribute
    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    @XmlElement(required = true)
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Date getStart() {
        return start;
    }

    public void setStart(Date start) {
        this.start = start;
    }

    public Date getEnd() {
        return end;
    }

    public void setEnd(Date end) {
        this.end = end;
    }

    @XmlTransient
    public Collection<Person> getInscrits() {
        return Collections.unmodifiableCollection(inscrits);
    }

    public void setInscrits(Collection<Person> inscrits) {
        this.inscrits = inscrits;
    }

    protected void addPerson(Person person) {
        inscrits.add(person);
    }

    public void inscrire(Person person) {
        person.inscrire(this);
    }

    @Transient
    public Collection<String> getEmailsInscrits() {
        Collection<String> res = new ArrayList<>();
        for (Person p : inscrits) {
            res.add(p.getEmail());
        }
        return res;
    }

    public void setEmailsInscrits(Collection<String> emails) {
        for (String mail : emails) {
            Person p = new Person();
            p.setEmail(mail);
            addPerson(p);
        }
    }
}
